==> flutter_catalogue_widgets-0.0.16.tar.gz: lib/custom_switch.dart <==
/*
Description:
A widget that creates a custom toggle button or a switch button of boolean type.

Usage:
The user can pass in colour of the button when active and the colour of the track when the button is active.
The user can also pass on other parameters like inactive track .
See CustomTextFieldContents and CustomTextFieldParameters class definitons for more information.
The user also passes a callback function which is invoked when the Switch is used.
- The widget returns the state of the switch i.e true or false when submitted.
  
  onSwitchTap(bool sBool) {
      print(sBool);
    }

SwitchParameters finalObj = new SwitchParameters(inactiveTrackColor: Color.fromRGBO(200, 0, 0, 0.5), activeColor: Colors.redAccent, activeTrackColor: Colors.orangeAccent);

    CustomSwitch(param: finalObj, callbackSwitch: onSwitchTap)

    imports: 
    import 'package:flutter/material.dart';
    import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
    import 'custom_switch.dart';

Author:
Anubhav Sinha
*/

import 'package:flutter/material.dart';
import 'package:flutter_catalogue_widgets/widget-classesUsed.dart';

class CustomSwitch extends StatefulWidget {

  final SwitchParameters param;
  final void Function(bool) callbackSwitch;

  const CustomSwitch({
    Key key,

    this.param,
    this.callbackSwitch

  }) :
        super(key: key);
  @override
  _CustomSwitchState createState() => _CustomSwitchState(
      this.param,
      this.callbackSwitch
  );
}
class _CustomSwitchState extends State<CustomSwitch> {
  SwitchParameters param;
  void Function(bool) callbackSwitch;
  _CustomSwitchState(
      SwitchParameters param,
      Function(bool) callback
      ){
    this.param = param;
    this.callbackSwitch = callback;
  }
  bool val= false;
  @override
  Widget build(BuildContext context) {
// implement build
    if (param == null){
      return Switch(
        activeColor: Theme.of(context).buttonColor,
        activeTrackColor: Theme.of(context).buttonColor,
        value: val,
        onChanged: (bool e) => something(e) ,
        inactiveTrackColor: Theme.of(context).disabledColor,
      );
    }
    else {
      return Switch(
        activeColor: (param.activeColor != null)? param.activeColor: Theme.of(context).buttonColor,
        activeTrackColor: (param.activeTrackColor != null)? param.activeTrackColor: Theme.of(context).buttonColor,
        value: val,
        onChanged: (bool e) => something(e) ,
        inactiveTrackColor: (param.inactiveTrackColor != null)? param.inactiveTrackColor: Theme.of(context).disabledColor,
      );
    }

  }
  void something(bool e){
    setState(() {
      if (e) {
        val=true;
        e=true;
      }
      else {
        val=false;
        e=false;
      }
      callbackSwitch(val);
    });
  }
}

==> flutter_catalogue_widgets-0.0.25.tar.gz: lib/custom_switch.dart <==
/*
Description:
A widget that creates a custom toggle button or a switch button of boolean type.

Usage:
The user can pass in colour of the button when active and the colour of the track when the button is active.
The user can also pass on other parameters like inactive track .
See CustomTextFieldContents and CustomTextFieldParameters class definitons for more information.
The user also passes a callback function which is invoked when the Switch is used.
- The widget returns the state of the switch i.e true or false when submitted.
  
  onSwitchTap(bool sBool) {
      print(sBool);
    }

SwitchParameters finalObj = new SwitchParameters(inactiveTrackColor: Color.fromRGBO(200, 0, 0, 0.5), activeColor: Colors.redAccent, activeTrackColor: Colors.orangeAccent);

    CustomSwitch(param: finalObj, callbackSwitch: onSwitchTap)

    imports: 
    import 'package:flutter/material.dart';
    import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
    import 'custom_switch.dart';

Author:
Anubhav Sinha
*/

import 'package:flutter/material.dart';
import 'package:flutter_catalogue_widgets/widget-classesUsed.dart';

class CustomSwitch extends StatefulWidget {
  final SwitchParameters param;
  final void Function(bool) callbackSwitch;

  const CustomSwitch({Key key, this.param, this.callbackSwitch})
      : super(key: key);
  @override
  _CustomSwitchState createState() =>
      _CustomSwitchState(this.param, this.callbackSwitch);
}

class _CustomSwitchState extends State<CustomSwitch> {
  SwitchParameters param;
  void Function(bool) callbackSwitch;
  _CustomSwitchState(SwitchParameters param, Function(bool) callback) {
    this.param = param;
    this.callbackSwitch = callback;
  }
  bool val = false;
  @override
  Widget build(BuildContext context) {
// implement build
    if (param == null) {
      return Switch(
        activeColor: Theme.of(context).buttonColor,
        activeTrackColor: Theme.of(context).buttonColor,
        value: val,
        onChanged: (bool e) => something(e),
        inactiveTrackColor: Theme.of(context).disabledColor,
      );
    } else {
      return Switch(
        activeColor: (param.activeColor != null)
            ? param.activeColor
            : Theme.of(context).buttonColor,
        activeTrackColor: (param.activeTrackColor != null)
            ? param.activeTrackColor
            : Theme.of(context).buttonColor,
        value: val,
        onChanged: (bool e) => something(e),
        inactiveTrackColor: (param.inactiveTrackColor != null)
            ? param.inactiveTrackColor
            : Theme.of(context).disabledColor,
      );
    }
  }

  void something(bool e) {
    setState(() {
      if (e) {
        val = true;
        e = true;
      } else {
        val = false;
        e = false;
      }
      callbackSwitch(val);
    });
  }
}
